/*
{
    "CATEGORIES": [
        "Automatically Converted",
        "Shadertoy"
    ],
    "DESCRIPTION": "Automatically converted from https://www.shadertoy.com/view/Xdf3Rf by Forceflow.  Based on http://en.wikipedia.org/wiki/Sobel_operator, can be used for edge detection.\nA very basic example to start other work from (and also my first submission to shadertoy ;) )",
    "IMPORTED": {
    },
    "INPUTS": [
        {
            "NAME": "inputImage",
            "TYPE": "image"
        }
    ]
}

*/


// Basic sobel filter implementation
// Jeroen Baert - jeroen.baert@cs.kuleuven.be
// 
// www.forceflow.be


// Use these parameters to fiddle with settings
float step = 1.0;

float intensity(in vec4 color){
	return sqrt((color.x*color.x)+(color.y*color.y)+(color.z*color.z));
}

vec3 sobel(float stepx, float stepy, vec2 center){
	// get samples around pixel
    float tleft = intensity(IMG_NORM_PIXEL(inputImage,mod(center + vec2(-stepx,stepy),1.0)));
    float left = intensity(IMG_NORM_PIXEL(inputImage,mod(center + vec2(-stepx,0),1.0)));
    float bleft = intensity(IMG_NORM_PIXEL(inputImage,mod(center + vec2(-stepx,-stepy),1.0)));
    float top = intensity(IMG_NORM_PIXEL(inputImage,mod(center + vec2(0,stepy),1.0)));
    float bottom = intensity(IMG_NORM_PIXEL(inputImage,mod(center + vec2(0,-stepy),1.0)));
    float tright = intensity(IMG_NORM_PIXEL(inputImage,mod(center + vec2(stepx,stepy),1.0)));
    float right = intensity(IMG_NORM_PIXEL(inputImage,mod(center + vec2(stepx,0),1.0)));
    float bright = intensity(IMG_NORM_PIXEL(inputImage,mod(center + vec2(stepx,-stepy),1.0)));
 
	// Sobel masks (see http://en.wikipedia.org/wiki/Sobel_operator)
	//        1 0 -1     -1 -2 -1
	//    X = 2 0 -2  Y = 0  0  0
	//        1 0 -1      1  2  1
	
	// You could also use Scharr operator:
	//        3 0 -3        3 10   3
	//    X = 10 0 -10  Y = 0  0   0
	//        3 0 -3        -3 -10 -3
 
    float x = tleft + 2.0*left + bleft - tright - 2.0*right - bright;
    float y = -tleft - 2.0*top - tright + bleft + 2.0 * bottom + bright;
    float color = sqrt((x*x) + (y*y));
    return vec3(color,color,color);
 }

void main() {

	vec2 uv = gl_FragCoord.xy / RENDERSIZE.xy;
	vec4 color = IMG_NORM_PIXEL(inputImage,mod(uv.xy,1.0));
	gl_FragColor.xyz = sobel(step/RENDERSIZE[0], step/RENDERSIZE[1], uv);
}
